VimbaLibrary

Struct VimbaLibrary 

pub struct VimbaLibrary {
    pub vimba_lib: VimbaC,
    /* private fields */
}

Fields

vimba_lib: VimbaC

Implementations

Source

impl VimbaLibrary

pub fn new() -> Result<Self, Error>

pub unsafe fn shutdown(&self)

This is unsafe because really you should drop VimbaLibrary rather than this. If you are using this, it cannot be guaranteed that VmbShutdown will not be called again.

Safety

The caller must ensure that VmbShutdown is not called again (for example via dropping VimbaLibrary) after this call.

pub fn from_dynamic_lib_path<P: AsRef<Path>>( vimbac_path: P, ) -> Result<Self, Error>

pub fn n_cameras(&self) -> Result<usize>

pub fn camera_info(&self, n_count: usize) -> Result<Vec<CameraInfo>>